Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(321)

Unified Diff: content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java

Issue 2154883003: Make ContentVideoView progress view visible in WebView (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Take into account whether Spitzer is enabled Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java b/content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java
index 198a5a2bb18ed9c744e5b1257fac6adbb8823a6a..db04221abe07e6f0dbbc5e57af0f922ffac22b7c 100644
--- a/content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java
+++ b/content/public/android/java/src/org/chromium/content/browser/ContentVideoViewEmbedder.java
@@ -12,7 +12,8 @@ import android.view.View;
* This contains the superset of callbacks that must be implemented by the embedder
* to support fullscreen video.
*
* {@link #enterFullscreenVideo(View)} and {@link #exitFullscreenVideo()} must be implemented,
* {@link #getVideoLoadingProgressView()} is optional, and may return null if not required.
*
* The implementer is responsible for displaying the Android view when
@@ -33,6 +34,13 @@ public interface ContentVideoViewEmbedder {
public void exitFullscreenVideo();
/**
+ * Called during {@link ContentVideoView} creation. If this methos returns true,
+ * {@link ContentVideoView} will have a SurfaceView underlay that will display
+ * actual video playback. Must be implemented.
+ */
+ public boolean needsVideoSurfaceView();
+
+ /**
* Allows the embedder to replace the view indicating that the video is loading.
* If null is returned, the default video loading view is used.
*/
@@ -12,7 +12,8 @@ import android.view.View;
* to support fullscreen video.
*
- * {@link #enterFullscreenVideo(View)} and {@link #exitFullscreenVideo()} must be implemented,
+ * {@link #enterFullscreenVideo(View)}, {@link #exitFullscreenVideo()} and
+ * {@link #needsVideoSurfaceView} must be implemented,
* {@link #getVideoLoadingProgressView()} is optional, and may return null if not required.
*

Powered by Google App Engine
This is Rietveld 408576698